@@ -5,7 +5,7 @@
 # This file is part of mdutils. https://github.com/didix21/mdutils
 #
 # MIT License: (C) 2020 Dídac Coll
-from typing import Optional
+from typing import Optional, Union, Iterable
 
 
 class Table:
@@ -15,7 +15,7 @@ class Table:
         self.columns = 0
 
     @staticmethod
-    def _align(columns, text_align: Optional[str] = None) -> str:
+    def _align(columns: int, text_align: Optional[Union[str, Iterable]] = None) -> str:
         """ This private method it's in charge of aligning text of a table.
 
         - notes: more information about `text_align`
@@ -32,26 +32,44 @@ class Table:
         """
 
         column_align_string = ''
-
-        if text_align == 'center':
-
-            column_align_string = '|' + ''.join([' :---: |' for _ in range(columns)])
-
-        elif text_align == 'left':
-
-            column_align_string = '|' + ''.join([' :--- |' for _ in range(columns)])
-
-        elif text_align == 'right':
-
-            column_align_string = '|' + ''.join([' ---: |' for _ in range(columns)])
-
+        ta2pat={ # text_align to pattern translator
+            'center': ' :---: |',
+            'left': ' :--- |',
+            'right': ' ---: |',
+            None: ' --- |'
+        }
+        if type(text_align) == str:
+            
+            text_align = [text_align.lower()]*columns
+            
         elif text_align is None:
-
-            column_align_string = '|' + ''.join([' --- |' for _ in range(columns)])
+            
+            text_align = [None]*columns
+            
+        else:
+            
+            text_align = list(text_align)[:columns] # make a local redimensionnable copy
+        
+        if len(text_align) < columns:
+            
+            text_align += [None]*(columns-len(text_align))
+            
+        column_align_string = '|'
+        for i,ta in enumerate(text_align):
+            
+            if not ta is None:
+                
+                ta = ta.lower()
+                
+            if ta not in ta2pat:
+                
+                raise ValueError(f"text_align's expected value: 'right', 'center', 'left' or None , but in column {i+1} text_align = '{ta}'")
+            
+            column_align_string += ta2pat[ta]
 
         return column_align_string
 
-    def create_table(self, columns: int, rows: int, text: [str], text_align: Optional[str] = None):
+    def create_table(self, columns: int, rows: int, text: [str], text_align: Optional[Union[str, list]] = None):
         """This method takes a list of strings and creates a table.
 
             Using arguments ``columns`` and ``rows`` allows to create a table of *n* columns and *m* rows.
@@ -61,7 +79,7 @@ class Table:
         :param int rows: number of rows of the table.
         :param text: a list of strings.
         :type text: list of str
-        :param str text_align: text align argument. Values available are: ``'right'``, ``'center'``, and ``'left'``.
+        :param str_or_list text_align: text align argument. Values available are: ``'right'``, ``'center'``, ``'left'`` and ``None`` (default). If text_align is a list then individual alignment can be set for each column.
         :return: a markdown table.
         :rtype: str
 
@@ -88,23 +106,16 @@ class Table:
         column_align_string = self._align(columns, text_align)
         index = 0
         if columns * rows == len(text):
-            if text_align is None or text_align.lower() in ('right', 'center', 'left'):
-                for row in range(rows + 1):
-                    if row == 1:
-                        table += column_align_string  # Row align, Example: '| :---: | :---: | ... | \n'
-                    else:
-                        table += '|'
-                        for _ in range(columns):
-                            table += text[index] + '|'
-                            index += 1
-
-                    table += '\n'
-
-                return table
-
-            else:
-                raise ValueError("text_align's expected value: 'right', 'center', 'left' or None , but text_align = "
-                                 + text_align.lower())
+            for row in range(rows + 1):
+                if row == 1:
+                    table += column_align_string  # Row align, Example: '| :---: | :---: | ... | \n'
+                else:
+                    table += '|'
+                    for _ in range(columns):
+                        table += str(text[index]) + '|'
+                        index += 1
+                table += '\n'
+            return table
         else:
             raise ValueError("columns * rows is not equal to text length")
 
