@@ -16,7 +16,7 @@ class TableOfContents:
 
         :param elements: contain all the headers defined on the main class.
         :param tab: Inserts tabulations.
-        :param depth: allows to include Headers 1 and 2 or only Headers of level 1. Possibly values 1 or 2.
+        :param depth: allows to include atx headers 1 through 6. Possible values: 1, 2, 3, 4, 5, or 6.
         :type elements: list
         :type tab: str
         :type depth: int
@@ -25,11 +25,8 @@ class TableOfContents:
         elements_to_string = ""
         for item in elements:
             if isinstance(item, list):
-                if item and depth == 2:
-                    if tab == '\t':
-                        elements_to_string += self._loop_through(item, tab='\t\t')
-                    else:
-                        elements_to_string += self._loop_through(item, tab='\t')
+                if item and depth > 1:
+                    elements_to_string += self._loop_through(item, tab=tab+'\t', depth=depth-1)
             else:
                 elements_to_string += '\n' + tab + '* [' + item + '](#' \
                                       + re.sub('[^a-z0-9_\-]', '', item.lower().replace(' ', '-')) + ')'
@@ -37,23 +34,21 @@ class TableOfContents:
         return elements_to_string
 
     def create_table_of_contents(self, array_of_title_contents, depth=1):
-        """This method can create a table of contents using an array of the different titles. The deep can be changed.
-        Only accepts 1 or 2.
-
+        """This method can create a table of contents using an array of the different titles. The depth can be changed.
         :param array_of_title_contents: a string list with the different headers.
         :type array_of_title_contents: list
-        :param depth: allows to include Headers 1 and 2 or only Headers of level 1. Possibly values 1 or 2.
+        :param depth: allows to include atx headers 1 through 6. Possible values: 1, 2, 3, 4, 5, or 6.
         :type depth: int
         :return: return a string ready to be written to a Markdown file.
         :rtype: str
         """
-        if depth in (1, 2):
+        if depth in range(1,7):
             table_of_contents = ""
             table_of_contents += self._loop_through(array_of_title_contents, depth=depth)
             table_of_contents += '\n'
             return table_of_contents
         else:
-            raise ValueError("depth's expected value: 1 or 2, but depth = " + str(depth))
+            raise ValueError("depth's expected value: between 1 and 6, but depth = " + str(depth))
 
 
 if __name__ == "__main__":
